@@ -2,6 +2,7 @@ use crate::event::bootloader_event::*;
 use crate::event::general_event::*;
 use crate::event::programmer_event::*;
 use crate::event::bcm_event::*;
+use crate::event::internal_event::*;
 
 #[derive(Debug, PartialEq)]
 pub enum EventPacketError {
@@ -19,5 +20,8 @@ pub enum EventPacket {
     ProgrammerHello(ProgrammerHelloEvent),
     ProgrammerStartUpload(ProgrammerStartUploadEvent),
 
-    BcmChangeBrightness(BcmChangeBrightnessEvent)
+    BcmChangeBrightness(BcmChangeBrightnessEvent),
+
+    InternalButtonPressed(InternalButtonPressedEvent),
+    InternalButtonReleased(InternalButtonReleasedEvent),
 }
